=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2009-02-17 00:54:19 +0000
+++ bzrlib/knit.py	2009-02-17 01:25:34 +0000
@@ -1478,6 +1478,12 @@
                     del buffered_index_entries[key]
 
     def get_missing_compression_parent_keys(self):
+        """Return an iterable of keys of missing compression parents.
+
+        Check this after calling insert_record_stream to find out if there are
+        any missing compression parents.  If there are, the records that
+        depend on them are *not* yet inserted.
+        """
         return self._buffered_index_entries.keys()
 
     def iter_lines_added_or_present_in_keys(self, keys, pb=None):

=== modified file 'bzrlib/tests/test_versionedfile.py'
--- bzrlib/tests/test_versionedfile.py	2009-02-17 00:54:19 +0000
+++ bzrlib/tests/test_versionedfile.py	2009-02-17 01:25:34 +0000
@@ -2015,7 +2015,8 @@
         """Insertion where a needed basis is not included notifies the caller
         of the missing basis.  That basis can be added in a second
         insert_record_stream call that does not need to repeat records present
-        in the previous stream.
+        in the previous stream.  The record(s) that required that basis are
+        fully inserted once their basis is no longer missing.
         """
         if not self.support_partial_insertion:
             raise TestNotApplicable(

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2009-02-17 00:54:19 +0000
+++ bzrlib/versionedfile.py	2009-02-17 01:25:34 +0000
@@ -925,6 +925,15 @@
 
     has_key = index._has_key_from_parent_map
 
+    def get_missing_compression_parent_keys(self):
+        """Return an iterable of keys of missing compression parents.
+
+        Check this after calling insert_record_stream to find out if there are
+        any missing compression parents.  If there are, the records that
+        depend on them are *not* yet inserted.
+        """
+        raise NotImplementedError(self.get_missing_compression_parent_keys)
+
     def insert_record_stream(self, stream):
         """Insert a record stream into this container.
 
@@ -1160,7 +1169,8 @@
         return sha1s
 
     def get_missing_compression_parent_keys(self):
-        # XXX
+        """See VersionedFile.get_missing_compression_parent_keys."""
+        # weaves don't support partial inserts
         return []
     
     def insert_record_stream(self, stream):

